@@ -1,6 +1,6 @@
-from FlaUILibrary.robotframework import keyword
-from FlaUILibrary.flaui.util import InterfaceType
-from FlaUILibrary.flaui.module import (Window, Element)
+from robotlibcore import keyword
+from FlaUILibrary.flaui.interface import InterfaceType
+from FlaUILibrary.flaui.module import Window
 
 
 class WindowKeywords:
@@ -9,15 +9,17 @@ class WindowKeywords:
     """
 
     def __init__(self, module):
-        """Constructor for mouse keywords.
+        """
+        Constructor for mouse keywords.
 
         ``module`` UIA3 module to handle element interaction.
         """
-        self.module = module
+        self._module = module
 
     @keyword
     def close_window(self, identifier, msg=None):
-        """Try to close window from element.
+        """
+        Try to close window from element.
 
         Arguments:
         | Argument   | Type   | Description                             |
@@ -29,7 +31,7 @@ class WindowKeywords:
         | Close Window  <XPATH_TO_APPLICATION_WINDOW> |
 
         """
-        element = self.module.action(Element.Action.GET_ELEMENT, identifier, msg)
-        self.module.action(Window.Action.CLOSE_WINDOW,
-                           self.module.cast_element_to_type(element, InterfaceType.WINDOW),
-                           msg)
+        element = self._module.get_element(identifier, InterfaceType.WINDOW, msg=msg)
+        self._module.action(Window.Action.CLOSE_WINDOW,
+                            Window.Container(element=element),
+                            msg)
